@@ -4,7 +4,7 @@ import string
 import os
 import re
 
-driven_down_doc = None
+driven_doc = None
 
 # text sections
 EN_PRE_CONFIG = 0
@@ -391,7 +391,7 @@ class RouteDocUnit(AbstractDocUnit):
 
 
 
-class DrivenDownDoc(object):
+class DrivenDoc(object):
     def __init__(self):
         self.title = None
         self.author = None
@@ -567,17 +567,17 @@ def initialize(doc_filepath, debug_output=None):
 
     if print_feed:
         print '@@@@@@@@@@@@@@@@@@@@@@@@@ dd FEED @@@@@@@@@@@@@@@@@@@@@@@@@'
-    global driven_down_doc
-    driven_down_doc = DrivenDownDoc()
+    global driven_doc
+    driven_doc = DrivenDoc()
     root_dir, basename = os.path.split(doc_filepath)
-    feed_file(driven_down_doc, doc_filepath, root_dir, line_feed, file_feed, print_feed, rcrsn_lvl=0)
+    feed_file(driven_doc, doc_filepath, root_dir, line_feed, file_feed, print_feed, rcrsn_lvl=0)
     if print_feed:
         print '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@'
 
 
 link_to_file_pattern = '(^%# (\w+.*)|^#### ((config|predict|response|runtime|status)/\w+.*))'
 regex = re.compile(link_to_file_pattern)
-def feed_file(driven_down_doc, filepath, root_dir, line_feed, file_feed, print_feed, rcrsn_lvl=0):
+def feed_file(driven_doc, filepath, root_dir, line_feed, file_feed, print_feed, rcrsn_lvl=0):
     full_filepath = os.path.join(root_dir, filepath)
     if file_feed:
         print 'docdriven: '+full_filepath
@@ -599,38 +599,38 @@ def feed_file(driven_down_doc, filepath, root_dir, line_feed, file_feed, print_f
                 path = 'chapter/'+path
             include_filepath = os.path.join(root_dir, path)
             if match.groups()[3] is not None:
-                feed_line(driven_down_doc, ('#### '+match.groups()[3]+'\n'), from_filekey, line_feed, print_feed, rcrsn_lvl+1)
+                feed_line(driven_doc, ('#### '+match.groups()[3]+'\n'), from_filekey, line_feed, print_feed, rcrsn_lvl+1)
                 if match.groups()[3] == 'runtime':
-                    feed_line(driven_down_doc, ('~'*42)+'  python\n', from_filekey, line_feed, print_feed, rcrsn_lvl+1)
+                    feed_line(driven_doc, ('~'*42)+'  python\n', from_filekey, line_feed, print_feed, rcrsn_lvl+1)
                 else:
-                    feed_line(driven_down_doc, ('~'*44)+'  json\n', from_filekey, line_feed, print_feed, rcrsn_lvl+1)
-                feed_file(driven_down_doc, include_filepath, root_dir, line_feed, file_feed, print_feed, rcrsn_lvl+1)
-                feed_line(driven_down_doc, ('~'*50)+'\n', from_filekey, line_feed, print_feed, rcrsn_lvl+1)
+                    feed_line(driven_doc, ('~'*44)+'  json\n', from_filekey, line_feed, print_feed, rcrsn_lvl+1)
+                feed_file(driven_doc, include_filepath, root_dir, line_feed, file_feed, print_feed, rcrsn_lvl+1)
+                feed_line(driven_doc, ('~'*50)+'\n', from_filekey, line_feed, print_feed, rcrsn_lvl+1)
             else:
-                feed_file(driven_down_doc, include_filepath, root_dir, line_feed, file_feed, print_feed, rcrsn_lvl+1)
+                feed_file(driven_doc, include_filepath, root_dir, line_feed, file_feed, print_feed, rcrsn_lvl+1)
         else:
-            feed_line(driven_down_doc, line, from_filekey, line_feed, print_feed, rcrsn_lvl)
+            feed_line(driven_doc, line, from_filekey, line_feed, print_feed, rcrsn_lvl)
     feeder_file.close()
 
-def feed_line(driven_down_doc, line, from_filekey, line_feed, print_feed, rcrsn_lvl):
+def feed_line(driven_doc, line, from_filekey, line_feed, print_feed, rcrsn_lvl):
     if print_feed:
         print ' '*(4*rcrsn_lvl)+'| '+line
     if line_feed:
         print 'docdriven:    '+line.rstrip()
-    driven_down_doc.feed_line(line, from_filekey)
+    driven_doc.feed_line(line, from_filekey)
 
 def print_to_files(parent_dirpath, dd_all_response=True):
     print 'parent_dirpath='+str(parent_dirpath)
-    global driven_down_doc
-    filepath = os.path.join(parent_dirpath, title2filename(driven_down_doc.title))
+    global driven_doc
+    filepath = os.path.join(parent_dirpath, title2filename(driven_doc.title))
     report_filepath = os.path.join(parent_dirpath, 'reports/')
-    report_filepath = os.path.join(report_filepath, title2filename(driven_down_doc.title))
+    report_filepath = os.path.join(report_filepath, title2filename(driven_doc.title))
 
     dd_all_file = open(filepath+'.all.dd', 'w')
-    driven_down_doc.print_all_to_file(dd_all_file, dd_all_response)
+    driven_doc.print_all_to_file(dd_all_file, dd_all_response)
     dd_all_file.close()
 
-    driven_down_doc.print_nav_to_file(parent_dirpath, response=dd_all_response)
+    driven_doc.print_nav_to_file(parent_dirpath, response=dd_all_response)
 
     status_filepath = report_filepath+'.status'
     try:
@@ -639,7 +639,7 @@ def print_to_files(parent_dirpath, dd_all_response=True):
        pass
     status_report = open(status_filepath, 'w').close()
     status_report = open(status_filepath, 'w')
-    driven_down_doc.print_status_report(status_report)
+    driven_doc.print_status_report(status_report)
     status_report.close()
 
     ch_status_filepath = status_filepath.replace('.status', '.ch.status')
@@ -649,13 +649,13 @@ def print_to_files(parent_dirpath, dd_all_response=True):
         pass
     ch_status_file = open(ch_status_filepath, 'w').close()
     ch_status_file = open(ch_status_filepath, 'w')
-    driven_down_doc.print_ch_status_report(ch_status_file)
+    driven_doc.print_ch_status_report(ch_status_file)
     ch_status_file.close()
 
 
 def get_json_doc_structure():
-    global driven_down_doc
-    return driven_down_doc.get_json_doc_structure()
+    global driven_doc
+    return driven_doc.get_json_doc_structure()
 
 if __name__ == '__main__':
     routes_filepath = '/Users/Jon/dev/iit/nebula1/cwautopro/routes.dd'
