@@ -12,8 +12,8 @@ class DocDrivenTestCase(unittest.TestCase):
     default_base_url='http://216.224.141.220:5438'
     default_http_headers = {'Content-type': 'application/json', 'Accept': 'text/plain'}
 
-    def __init__(self, driven_down_doc):
-        self.driven_down_doc = driven_down_doc
+    def __init__(self, driven_doc):
+        self.driven_doc = driven_doc
 
     @classmethod
     def GET(cls, path, base_url=default_base_url, http_headers=default_http_headers):
@@ -386,11 +386,11 @@ class DocDrivenTestCase(unittest.TestCase):
 
 default_base_url='http://216.224.141.220:5438'
 default_http_headers = {'Content-type': 'application/json', 'Accept': 'text/plain'}
-def init_DocDrivenTestCase(driven_down_doc, base_url=default_base_url, http_headers=default_http_headers):
+def init_DocDrivenTestCase(driven_doc, base_url=default_base_url, http_headers=default_http_headers):
 
     # REMOVE TEST CASES FROM LAST TIME -- EACH INIT SHOULD BE FRESH
 
-    DocDrivenTestCase.driven_down_doc = driven_down_doc
+    DocDrivenTestCase.driven_doc = driven_doc
     DocDrivenTestCase.default_base_url = base_url
     DocDrivenTestCase.default_http_headers = http_headers
 
@@ -401,7 +401,7 @@ def init_DocDrivenTestCase(driven_down_doc, base_url=default_base_url, http_head
     setattr(DocDrivenTestCase, 'test_empty', empty_test)
 
     # we add one test method per chapter
-    for chapter in DocDrivenTestCase.driven_down_doc.chapter_list:
+    for chapter in DocDrivenTestCase.driven_doc.chapter_list:
         DocDrivenTestCase.insert_test_method(chapter)
 
     return DocDrivenTestCase
